@@ -198,7 +198,7 @@ def get_pyechart_line_obj(target_df: pd.DataFrame, line_title: str = ''):
     :return:
     """
     line = (Line(
-        init_opts=opts.InitOpts(width='100%', height="700px", theme=ThemeType.CHALK)
+        init_opts=opts.InitOpts(width='100%', height="700px", theme=ThemeType.DARK)
     ).add_xaxis(
         [d for d in list(target_df.index)]
     ).set_global_opts(
